<?php
/**
 * Validação de datas inicial, final e saida antes de apurar o faturamento
 */
namespace Faturamento\Logic\ApuracaoFaturamento\Exception;

class DataApuracao extends \Faturamento\Logic\Exception
{

    private $messageName;
    const ALERTA = 0;

    /**
     * Construtor.
     *
     * Recebe o nome da mensagem cadastrada no setforms.
     *
     * @param string $messageName
     * @param string $message
     * @param int $code
     * @param \Exception|null $previous
     */
    public function __construct($messageName, $code = 0, \Exception $previous = null)
    {
        parent::__construct($messageName, $code, $previous);
        $this->messageName = $messageName;
    }


    /**
     * Retorna o nome da mensagem cadastrada no Setforms para esta excecao.
     *
     * @return string
     */
    public function getMessageName()
    {
        return $this->messageName;
    }

    /**
     * Data inicial da apuração nao foi informada
     * @static
     * @throws DataApuracao
     */
    public static function informaDataInicioApuracao()
    {
        throw new self ("fai00800_informa_data_inic_apur", self::ALERTA);
    }


    /**
     * Data final da apuração nao foi informada
     * @static
     * @throws DataApuracao
     */
    public static function informaDataFimApuracao()
    {
        throw new self ("fai00800_informa_data_fin_apur", self::ALERTA);
    }


    /**
     * Data final da apuração deve ser maior ou igual a data inicial de apuração.
     * @static
     * @throws DataApuracao
     */
    public static function dataFinalMenorDataInicialApuracao()
    {
        throw new self("fai00800_dtfinapur_maior_igual_dtiniapur", self::ALERTA);
    }


    public static function dataSaidaMenorDataFimApuracao()
    {
        throw new self("fai00800_dtsaida_maior_igual_dtfinapur", self::ALERTA);
    }

}